install.packages("extrafont")
library(extrafont)
font_import()



source("http://methylkit.googlecode.com/files/install.methylKit.R")

# READ METHYLATION FILES
install.methylKit(ver="0.5.6",dependencies=TRUE)
library(methylKit)
install.packages("data.table")
source("http://www.bioconductor.org/biocLite.R")
biocLite("GenomicRanges")
library(data.table) 
library(GenomicRanges)

setwd("/Users/claireellis/Desktop")

#get gonad BSMAP reads in

#read in formatted BSmap data for male gonad
gonad=read("TJGR_GonadPE_BS_v9_90_CG_methylkit.txt.txt",sample.id="test",assembly="mm9",header=T, context="CpG", resolution="base",
          pipeline=list(fraction=TRUE,chr.col=2,start.col=3,end.col=3,
                        coverage.col=5,strand.col=4,freqC.col=6))
 
# GET DESCRIPTIVE STATS ON METHYLATION
# get methylation statistics on obj which is a class of methylRawList
getMethylationStats(gonad,plot=F,both.strands=F)

# plot methylation statistics on obj which is a class of methylRawList
getMethylationStats(gonad,plot=T,both.strands=F,labels=TRUE)

getCoverageStats(gonad, plot=T, both.strands=F)

# get gill BSMAP data files
gill=read("~/Desktop/TJGR_gillMBD_BS_v9_10x_methylkit.tabular",sample.id="test",assembly="mm9",header=TRUE, context="CpG", resolution="base",
pipeline=list(fraction=TRUE,chr.col=1,start.col=2,end.col=2,strand.col=3, 
coverage.col=4,freqC.col=5))  

# GET DESCRIPTIVE STATS ON METHYLATION
# get methylation statistics on obj which is a class of methylRawList
getMethylationStats(gill,plot=F,both.strands=F)

# plot methylation statistics on obj which is a class of methylRawList
getMethylationStats(gill,plot=T,both.strands=F)

# plot coverage statistics on gill
getCoverageStats(gill, plot=T, both.strands=F)

# see what the data looks like for Gonad in methylRawList
head(gonad)

# see what the data looks like for Gill in methylRawList
head(gill)

# GET BASES COVERED BY ALL SAMPLES AND CLUSTER SAMPLES
# generating a methyllist for differential methylation analyses
file <- list("~/Desktop/TJGR_GonadPE_BS_v9_90_CG_methylkit_modified.txt","~/Desktop/TJGR_gillMBD_BS_v9_10x_methylkit_modified.tabular")
oyster=read(file,pipeline=list(fraction=TRUE,chr.col=1,start.col=2,end.col=2,
strand.col=3,coverage.col=4,freqC.col=5),
sample.id=list("~/Desktop/TJGR_GonadPE_BS_v9_90_CG_methylkit_modified.txt","~/Desktop/TJGR_gillMBD_BS_v9_10x_methylkit_modified.tabular"),assembly="v9",treatment=c(1,0))
#QC
getMethylationStats(oyster[[1]],plot=F,both.strands=F)
getMethylationStats(oyster[[2]],plot=T,both.strands=F)
#unite the samples to create a list of CpG covered by all samples

# merge all samples to one table by using base-pair locations that are covered in all samples
#setting destrand=TRUE, will merge reads on both strands of a CpG dinucleotide.  This provies better coverage, but only advised when looking at CpG methylation
meth<-unite(oyster,destrand=FALSE)
head(meth)

getCorrelation(meth)

# cluster all samples using correlation distance and return a tree object for plclust
hc=clusterSamples(meth, dist="correlation", method="ward", plot=FALSE)

# cluster all samples using correlation distance and plot hiarachical clustering
clusterSamples(meth, dist="correlation", method="ward", plot=TRUE)

# screeplot of principal component analysis.
PCASamples(meth, screeplot=TRUE)

# principal component anlaysis of all samples.
PCASamples(meth)

# CALCULATE DIFFERENTIAL METHYLATION
# calculate differential methylation p-values and q-values
myDiff=calculateDiffMeth(meth)

# write csv file for differentially methylated bases
write.csv(myDiff,file="diffmethylation")

# check how data part of methylDiff object looks like
head(myDiff)

# get differentially methylated regions with 25% difference and qvalue<0.01
myDiff25p=get.methylDiff(myDiff,difference=25,qvalue=0.01)

# get differentially hypo methylated regions with 25% difference and qvalue<0.01
myDiff25pHypo=get.methylDiff(myDiff,difference=25,qvalue=0.01, type="hypo")

# write csv file for hypo- methylated bases
write.csv(myDiff,file="hypo_diffmethylation")

# get differentially hyper methylated regions with 25% difference and qvalue<0.01
myDiff25pHyper=get.methylDiff(myDiff,difference=25,qvalue=0.01,type="hyper")

# write csv file for hyer- methylated bases
write.csv(myDiff,file="hyper_diffmethylation")

myDiff25pHypo=get.methylDiff(gonad,difference=25,qvalue=0.01, type="hypo")

                        